@@ -13,7 +13,7 @@ c fortran version of C routine by Ken McElvain
 c
 
       implicit real*8 (a-h,o-z)
-      include 'bounds.cmn'
+      include 'bounds.h'
 
 
       dimension xc(nc+1),yc(nc+1)
